<?xml version="1.0" encoding="iso-8859-1"?>
<!DOCTYPE xsl:stylesheet [

<!ENTITY space '<xsl:text xmlns:xsl="http://www.w3.org/1999/XSL/Transform"> </xsl:text>'>
<!ENTITY cr '<xsl:text xmlns:xsl="http://www.w3.org/1999/XSL/Transform">&#x0a;</xsl:text>'>
<!ENTITY tab '<xsl:text xmlns:xsl="http://www.w3.org/1999/XSL/Transform">&#x09;</xsl:text>'>

<!ENTITY % CommonDTD SYSTEM "common.dtd">
%CommonDTD;

]>

<xsl:stylesheet
    version="1.0"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:lxslt="http://xml.apache.org/xslt"
    xmlns:exslt="http://exslt.org/common"
    xmlns:x="http://xml.usagiyojimbo.com/x/"
    xmlns:date="http://exslt.org/dates-and-times"
        extension-element-prefixes="exslt date"
>
<xsl:import href="synopses-common.xsl" />
<xsl:import href="functions/date.date.template.xsl" />
<xsl:output
    method="html" indent="no" encoding="iso-8859-1"
/>

<xsl:param name="ref"/>
<xsl:param name="top">../</xsl:param>
<xsl:param name="dest">../public_html/</xsl:param>

<xsl:template match="/">
    <xsl:choose>
        <xsl:when test="$ref != ''">
            <xsl:apply-templates select="data/comics/comic[@id = concat('comic-',$ref) and title != '']"/>
        </xsl:when>
        <xsl:otherwise>
            <xsl:apply-templates select="data/comics/comic[@id and title != '']"/>
        </xsl:otherwise>
    </xsl:choose>
</xsl:template>

<xsl:template match="@* | node()" mode="comic-tpl">
    <xsl:param name="comic"/>
    <xsl:copy>
        <xsl:apply-templates select="@* | node()" mode="comic-tpl">
            <xsl:with-param name="comic" select="$comic"/>
        </xsl:apply-templates>
    </xsl:copy>
</xsl:template>

<xsl:template match="comic-header-title" mode="comic-tpl">
    <xsl:param name="comic"/>
    
    <xsl:value-of select="$comic/title"/>
    <xsl:if test="$comic/subtitle != ''">
        <xsl:text>: </xsl:text>
        <xsl:value-of select="$comic/subtitle"/>
    </xsl:if>
</xsl:template>

<xsl:template match="comic-title" mode="comic-tpl">
    <xsl:param name="comic"/>
    
    <h1 align="center">
        <xsl:value-of select="$comic/title"/>
    </h1>
    <xsl:if test="$comic/subtitle != ''">
        <h2 align="center">
            <em>
                <xsl:value-of select="$comic/subtitle"/>
            </em>
        </h2>
    </xsl:if>
</xsl:template>

<xsl:template match="comic-inter-links" mode="comic-tpl">
    <xsl:param name="comic"/>

    <xsl:variable name="prev" select="$comic/preceding-sibling::comic[@id and title != ''][1]"/>
    <xsl:variable name="next" select="$comic/following-sibling::comic[@id and title != ''][1]"/>
    
    <xsl:call-template name="inter-links">
        <xsl:with-param name="prev">
	    <xsl:if test="$prev">
		<xsl:call-template name="comic-link">
		    <xsl:with-param name="ref" select="$prev/@id"/>
		</xsl:call-template>
	    </xsl:if>
	</xsl:with-param>
        <xsl:with-param name="next">
	    <xsl:if test="$next">
		<xsl:call-template name="comic-link">
		    <xsl:with-param name="ref" select="$next/@id"/>
		</xsl:call-template>
	    </xsl:if>
	</xsl:with-param>
    </xsl:call-template>
</xsl:template>

<xsl:template match="comic-icons" mode="comic-tpl">
    <xsl:param name="comic"/>
    
    <xsl:variable name="gap" select="node()"/>
    <xsl:variable name="ref" select="$comic/@id"/>
    
    <xsl:if test="$comic/cover">
	<xsl:for-each select="$comic/cover">
	    <xsl:if test="position() > 1">
		<xsl:apply-templates select="$gap" mode="comic-tpl">
                    <xsl:with-param name="comic" select="$comic"/>
                </xsl:apply-templates>
	    </xsl:if>
	    <xsl:call-template name="cover-img">
		<xsl:with-param name="name" select="@name"/>
		<xsl:with-param name="ref" select="$ref"/>
	    </xsl:call-template>
	</xsl:for-each>
    </xsl:if>
</xsl:template>

<xsl:template match="comic-toc" mode="comic-tpl">
    <xsl:param name="comic"/>
    
    <xsl:call-template name="insert-toc">
	<xsl:with-param name="key" select="$comic/@id"/>
    </xsl:call-template>
</xsl:template>

<xsl:template match="comic-intro-title" mode="comic-tpl">
    <xsl:param name="comic"/>
    
    <xsl:choose>
	<xsl:when test="$comic/intro/@title != ''">
	    <xsl:value-of select="$comic/intro/@title"/>
	</xsl:when>
	<xsl:otherwise>
	    <xsl:text>Introducion</xsl:text>
	</xsl:otherwise>
    </xsl:choose>
</xsl:template>

<xsl:template match="comic-intro-title" mode="x-comic-tpl">
    <xsl:param name="comic"/>
    <xsl:param name="content"/>
    
    <xsl:choose>
	<xsl:when test="$comic/intro/@title != ''">
	    <xsl:value-of select="$comic/intro/@title"/>
	</xsl:when>
	<xsl:otherwise>
	    <xsl:text>Introducion</xsl:text>
	</xsl:otherwise>
    </xsl:choose>
</xsl:template>

<xsl:template match="comic-intro" mode="comic-tpl">
    <xsl:param name="comic"/>
    
    <xsl:if test="$comic/intro/@by != ''">
	<xsl:text>by </xsl:text>
	<xsl:value-of select="$comic/intro/@by"/>
	<br/>&cr;
	<br/>&cr;
    </xsl:if>
    
    <xsl:apply-templates select="$comic/intro/node()"/>
</xsl:template>

<xsl:template match="comic-letters" mode="comic-tpl">
    <xsl:param name="comic"/>
    
    <xsl:apply-templates select="$comic/letters/node()"/>
</xsl:template>

<xsl:template match="comic-notes" mode="comic-tpl">
    <xsl:param name="comic"/>
    
    <xsl:apply-templates select="$comic/note"/>
</xsl:template>

<xsl:template match="comic-footer" mode="comic-tpl">
    <xsl:param name="comic"/>
    
    <xsl:copy-of select="$common-footer"/>
</xsl:template>

<xsl:template match="comic-if" mode="comic-tpl">
    <xsl:param name="comic"/>

    <xsl:choose>
        <xsl:when test="@test = 'intro'">
            <xsl:if test="$comic/intro/node()">
                <xsl:apply-templates select="node()" mode="comic-tpl">
                    <xsl:with-param name="comic" select="$comic"/>
                </xsl:apply-templates>
            </xsl:if>
        </xsl:when>
        <xsl:when test="@test = 'letters'">
            <xsl:if test="$comic/letters/node()">
                <xsl:apply-templates select="node()" mode="comic-tpl">
                    <xsl:with-param name="comic" select="$comic"/>
                </xsl:apply-templates>
            </xsl:if>
        </xsl:when>
        <xsl:when test="@test = 'notes'">
            <xsl:if test="$comic/note/node()">
                <xsl:apply-templates select="node()" mode="comic-tpl">
                    <xsl:with-param name="comic" select="$comic"/>
                </xsl:apply-templates>
            </xsl:if>
        </xsl:when>
        <xsl:otherwise>
            <xsl:message terminate="yes">comic-if: Error: Unknown test: '<xsl:value-of select="@test"/>'</xsl:message>
        </xsl:otherwise>
    </xsl:choose>
</xsl:template>

<xsl:template match="x:use" mode="comic-tpl">
    <xsl:param name="comic"/>
    
    <xsl:variable name="name" select="@name"/>
    <xsl:variable name="template" select="//x:define[@name = $name]/node()"/>
    <xsl:variable name="content" select="node()"/>
    <!-- <xsl:message>template=<xsl:value-of select="count($template)"/></xsl:message>
    <xsl:message>content=<xsl:value-of select="$content"/></xsl:message> -->

    <xsl:if test="$template">
        <xsl:apply-templates select="$template" mode="x-comic-tpl">
            <xsl:with-param name="comic" select="$comic"/>
            <xsl:with-param name="content" select="$content"/>
        </xsl:apply-templates>
    </xsl:if>
</xsl:template>

<xsl:template match="@* | node()" mode="x-comic-tpl">
    <xsl:param name="comic"/>
    <xsl:param name="content"/>

    <xsl:copy>
        <xsl:apply-templates select="@* | node()" mode="x-comic-tpl">
            <xsl:with-param name="comic" select="$comic"/>
            <xsl:with-param name="content" select="$content"/>
        </xsl:apply-templates>
    </xsl:copy>
</xsl:template>

<xsl:template match="x:contents" mode="x-comic-tpl">
    <xsl:param name="comic"/>
    <xsl:param name="content"/>

    <!-- <xsl:message>content=<xsl:value-of select="$content"/></xsl:message> -->
    <xsl:apply-templates select="$content" mode="x-comic-tpl">
        <xsl:with-param name="comic" select="$comic"/>
        <xsl:with-param name="content" select="$content"/>
    </xsl:apply-templates>
</xsl:template>

<xsl:template match="comic">
    <xsl:variable name="ref" select="@id"/>
    <xsl:variable name="comic" select="."/>
    <xsl:variable name="lmod">
	<xsl:choose>
	    <xsl:when test="@lmod">
		<xsl:value-of select="@lmod"/>
	    </xsl:when>
	    <xsl:otherwise>
		<xsl:call-template name="date:date"/>
	    </xsl:otherwise>
	</xsl:choose>
    </xsl:variable>
    <xsl:variable name="path" select="concat($dest,'comics/',substring($ref,7),'.html')"/>

    <xsl:variable name="template">
        <page lmod="{$lmod}">
            <xsl:apply-templates select="document('comic.tpl')/page/*" mode="comic-tpl">
                <xsl:with-param name="comic" select="$comic"/>
            </xsl:apply-templates>
        </page>
    </xsl:variable>
    <!-- - -><xsl:call-template name="debug-dump">
	<xsl:with-param name="data" select="exslt:node-set($template)"/>
    </xsl:call-template> <!- - -->
    
    <xsl:message>Writing comic <xsl:value-of select="$path"/>...</xsl:message>
    <exslt:document href="{$path}">
        <xsl:apply-templates select="exslt:node-set($template)"/>
    </exslt:document>
</xsl:template>

</xsl:stylesheet>
