<?xml version="1.0" encoding="iso-8859-1"?>

<xsl:stylesheet
    version="1.0"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
>

<xsl:template name="fix-path">
    <xsl:param name="path"/>

    <xsl:choose>
	<xsl:when test="starts-with($path,'$TOP/')">
	    <xsl:value-of select="concat($top,substring-after($path,'$TOP/'))"/>
	</xsl:when>
	<xsl:when test="starts-with($path,'http://')">
	    <xsl:value-of select="$path"/>
	</xsl:when>
	<xsl:when test="starts-with($path,'/') and $top != '/'">
	    <xsl:value-of select="concat($top,$path)"/>
	</xsl:when>
	<xsl:otherwise>
	    <xsl:value-of select="$path"/>
	</xsl:otherwise>
    </xsl:choose>
</xsl:template>

<xsl:template name="get-page-path">
    <xsl:param name="path"/>
    <!--
    <xsl:message>    get-page-path: path=<xsl:value-of select="$path"/></xsl:message>
    -->
    
    <xsl:variable name="doc" select="document($path)"/>
    <xsl:choose>
        <xsl:when test="$doc/page/@target-url != ''">
            <!--
            <xsl:message>    path=<xsl:value-of select="$path"/> <xsl:value-of select="$doc/page/@target-url"/></xsl:message>
            -->
            <xsl:call-template name="fix-path">
                <xsl:with-param name="path">
                    <xsl:value-of select="$doc/page/@target-url"/>
                </xsl:with-param>
            </xsl:call-template>
        </xsl:when>
        <xsl:otherwise>
            <xsl:call-template name="fix-path">
                <xsl:with-param name="path">
                    <xsl:value-of select="concat('$TOP/',substring($path,1,string-length($path)-5),'.html')"/>
                </xsl:with-param>
            </xsl:call-template>
        </xsl:otherwise>
    </xsl:choose>
</xsl:template>

<xsl:template name="get-url-or-page-path">
    <xsl:param name="path"/>

    <xsl:choose>
        <xsl:when test="substring($path,string-length($path)-4) = '.page'">
            <xsl:call-template name="get-page-path">
                <xsl:with-param name="path" select="$path"/>
            </xsl:call-template>
        </xsl:when>
        <xsl:otherwise>
            <xsl:call-template name="fix-path">
                <xsl:with-param name="path" select="$path"/>
            </xsl:call-template>
        </xsl:otherwise>
    </xsl:choose>
</xsl:template>

<xsl:template name="image-path-key">
    <xsl:param name="path"/>

    <xsl:choose>
	<xsl:when test="starts-with($path,'$TOP/')">
	    <xsl:value-of select="substring($path,6)"/>
	</xsl:when>
	<xsl:when test="starts-with($path,'/')">
	    <xsl:value-of select="substring($path,2)"/>
	</xsl:when>
	<xsl:when test="starts-with($path,'http://')">
	    <!-- no contents -->
	</xsl:when>
	<xsl:otherwise>
	    <xsl:value-of select="$path"/>
	</xsl:otherwise>
    </xsl:choose>
</xsl:template>

<xsl:template name="prefix-words">
    <xsl:param name="list"/>
    <xsl:param name="prefix"/>

    <xsl:if test="$list != ''">
	<xsl:variable name="word" select="substring-before($list, ' ')"/>
	<xsl:choose>
	    <xsl:when test="$word = ''">
		<xsl:value-of select="$prefix"/>
		<xsl:value-of select="$list"/>
	    </xsl:when>
	    <xsl:otherwise>
		<xsl:value-of select="$prefix"/>
		<xsl:value-of select="$word"/>
		<xsl:text> </xsl:text>
		
		<xsl:call-template name="prefix-words">
		    <xsl:with-param name="list" select="substring-after($list, ' ')"/>
		    <xsl:with-param name="prefix" select="$prefix"/>
		</xsl:call-template>
	    </xsl:otherwise>
	</xsl:choose>
    </xsl:if>
</xsl:template>

</xsl:stylesheet>
