<?xml version="1.0" encoding="iso-8859-1"?>
<!DOCTYPE stylesheet [

<!ENTITY % CommonDTD SYSTEM "common.dtd">
%CommonDTD;

]>

<xsl:stylesheet
    version="1.0"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:exslt="http://exslt.org/common"
    xmlns:func="http://exslt.org/functions"
        extension-element-prefixes="func exslt"
        exclude-result-prefixes="func exslt"
    xmlns:my="my://own.uri"
>
<xsl:import href="common.xsl" />

<xsl:variable name="imginfo" select="document('tmp/imageinfo.xml')"/>
<xsl:key name="imgInfoKey" match="image" use="@path"/>

<func:function name="my:lookup-image-info">
    <xsl:param name="key"/>

    <xsl:variable name="result">
	<xsl:for-each select="$imginfo">
	    <xsl:copy-of select="key('imgInfoKey', $key)"/>
	</xsl:for-each>
    </xsl:variable>

    <func:result select="exslt:node-set ($result)/image"/>
</func:function>

<xsl:template name="image">
    <xsl:param name="mode">icon</xsl:param>
    <xsl:param name="align" select="@align"/>
    <xsl:variable name="path-key">
	<xsl:call-template name="image-path-key">
	    <xsl:with-param name="path" select="@url"/>
	</xsl:call-template>
    </xsl:variable>
    <!-- - ->
    <xsl:if test="@src or @SRC">
	<xsl:message>Image with src/SRC="<xsl:value-of select="@src | @SRC"/>" found</xsl:message>
    </xsl:if>
    <!- - -->
    <!-- - ->
    <xsl:message>image url=<xsl:value-of select="@url"/></xsl:message>
    <!- - -->

    <xsl:choose>
        <xsl:when test="@icon and $mode = 'icon'">
            <xsl:variable name="icon-key">
		<xsl:call-template name="image-path-key">
		    <xsl:with-param name="path" select="@icon"/>
		</xsl:call-template>
            </xsl:variable>
            
            <a>
                <xsl:attribute name="href">
                    <xsl:call-template name="fix-path">
                        <xsl:with-param name="path" select="@url"/>
                    </xsl:call-template>
                </xsl:attribute>
                
                <img border="0">
                    <xsl:for-each select="@*">
                        <xsl:choose>
                            <xsl:when test="name() = 'icon'">
                                <xsl:attribute name="src">
                                    <xsl:call-template name="fix-path">
                                        <xsl:with-param name="path" select="."/>
                                    </xsl:call-template>
                                </xsl:attribute>
                            </xsl:when>
                            <xsl:when test="name() = 'width' or name() = 'height' or name() = 'align' or name() = 'url' or name() = 'icon-size'">
				<!-- ignore -->
			    </xsl:when>
                            <xsl:otherwise>
                                <xsl:copy>
                                    <xsl:apply-templates select="@*"/>
                                </xsl:copy>
                            </xsl:otherwise>
                        </xsl:choose>
                    </xsl:for-each>
		    <xsl:if test="$icon-key != ''">
			<xsl:variable name="info" select="my:lookup-image-info ($icon-key)"/>
			<xsl:if test="not($info)">
			    <xsl:message>img: Warning: No infos for <xsl:value-of select="$icon-key"/> found.</xsl:message>
			</xsl:if>
			<!-- - ->
			<xsl:message>img: <xsl:value-of select="$info/@width"/> found.</xsl:message>
			<!- - -->
			<xsl:if test="$info and $info/@width and $info/@height">
			    <xsl:attribute name="width"><xsl:value-of select="$info/@width"/></xsl:attribute>
			    <xsl:attribute name="height"><xsl:value-of select="$info/@height"/></xsl:attribute>
			</xsl:if>
		    </xsl:if>
                    <xsl:if test="$align != ''">
                        <xsl:attribute name="align">
                            <xsl:value-of select="$align"/>
                        </xsl:attribute>
                    </xsl:if>
                </img>
            </a>
        </xsl:when>
        <xsl:otherwise>
            <img>
                <xsl:for-each select="@*">
                    <xsl:choose>
                        <xsl:when test="name() = 'SRC' or name() = 'src'
                            or name() = 'url'">
                            <xsl:attribute name="src">
                                <xsl:call-template name="fix-path">
                                    <xsl:with-param name="path" select="."/>
                                </xsl:call-template>
                            </xsl:attribute>
                        </xsl:when>
                        <xsl:when test="name() = 'icon' or name() = 'align'">
                            <!-- filter out -->
                        </xsl:when>
                        <xsl:otherwise>
                            <xsl:copy-of select="."/>
                        </xsl:otherwise>
                    </xsl:choose>
                </xsl:for-each>
		<xsl:if test="not(@width) and not(@height) and $path-key != ''">
		    <xsl:variable name="info" select="my:lookup-image-info($path-key)"/>
		    <!-- <exslt:document href="debug.xml" output="xml">
			<root>
			    <xsl:copy-of select="$info"/>
			</root>
		    </exslt:document> -->
		    <xsl:if test="not($info) or not($info/@width) or not($info/@height)">
			<xsl:message>img: Warning: No infos for <xsl:value-of select="$path-key"/> found.</xsl:message>
		    </xsl:if>
		    <xsl:if test="$info and $info/@width and $info/@height">
			<xsl:attribute name="width"><xsl:value-of select="$info/@width"/></xsl:attribute>
			<xsl:attribute name="height"><xsl:value-of select="$info/@height"/></xsl:attribute>
		    </xsl:if>
		</xsl:if>
                <xsl:if test="$align != ''">
                    <xsl:attribute name="align">
                        <xsl:value-of select="$align"/>
                    </xsl:attribute>
                </xsl:if>
            </img>
        </xsl:otherwise>
    </xsl:choose>
</xsl:template>

<xsl:template name="insert-img">
    <xsl:param name="border"/>
    <xsl:param name="src"/>
    <xsl:param name="align"/>
    <xsl:param name="alt"/>
    <xsl:param name="width"/>
    <xsl:param name="height"/>
    
    <xsl:variable name="use-src">
	<xsl:call-template name="fix-path">
	    <xsl:with-param name="path" select="$src"/>
	</xsl:call-template>
    </xsl:variable>
    <xsl:choose>
	<xsl:when test="$width = '' or $height = ''">
	    <xsl:variable name="path-key">
		<xsl:call-template name="image-path-key">
		    <xsl:with-param name="path" select="$src"/>
		</xsl:call-template>
	    </xsl:variable>
	    <xsl:variable name="info" select="my:lookup-image-info($path-key)"/>
	    <xsl:if test="not($info)">
		<xsl:message>insert-img: Warning: No infos for <xsl:value-of select="$path-key"/> (src=<xsl:value-of select="$src"/>) found.</xsl:message>
	    </xsl:if>

	    <!-- - ->
	    <xsl:message>info=<xsl:value-of select="$info/@path"/> (<xsl:value-of select="$info/@width"/>x<xsl:value-of select="$info/@height"/>)</xsl:message> 
	    <!- - -->

	    <img>
		<xsl:if test="$alt != ''">
		    <xsl:attribute name="alt"><xsl:value-of select="$alt"/></xsl:attribute>
		</xsl:if>
		<xsl:if test="$border != ''">
		    <xsl:attribute name="border"><xsl:value-of select="$border"/></xsl:attribute>
		</xsl:if>
		    
		<xsl:attribute name="src"><xsl:value-of select="$use-src"/></xsl:attribute>
		<xsl:if test="$align != ''">
		    <xsl:attribute name="align"><xsl:value-of select="$align"/></xsl:attribute>
		</xsl:if>
		<xsl:if test="$info and $info/@width and $info/@height">
		    <xsl:attribute name="width"><xsl:value-of select="$info/@width"/></xsl:attribute>
		    <xsl:attribute name="height"><xsl:value-of select="$info/@height"/></xsl:attribute>
		</xsl:if>
	    </img>
	</xsl:when>
	<xsl:otherwise>
	    <!-- - ->
	    <xsl:message>width=<xsl:value-of select="$width"/></xsl:message>
	    <xsl:message>height=<xsl:value-of select="$height"/></xsl:message>
	    <!- - -->
	    
	    <img>
		<xsl:if test="$alt != ''">
		    <xsl:attribute name="alt"><xsl:value-of select="$alt"/></xsl:attribute>
		</xsl:if>
		<xsl:if test="$border != ''">
		    <xsl:attribute name="border"><xsl:value-of select="$border"/></xsl:attribute>
		</xsl:if>
		    
		<xsl:attribute name="src"><xsl:value-of select="$use-src"/></xsl:attribute>
		<xsl:if test="$align != ''">
		    <xsl:attribute name="align"><xsl:value-of select="$align"/></xsl:attribute>
		</xsl:if>
		<xsl:if test="$width != '' and $height != ''">
		    <xsl:attribute name="width"><xsl:value-of select="$width"/></xsl:attribute>
		    <xsl:attribute name="height"><xsl:value-of select="$height"/></xsl:attribute>
		</xsl:if>
	    </img>
	</xsl:otherwise>
    </xsl:choose>
</xsl:template>

</xsl:stylesheet>
